@@ -180,14 +180,14 @@ class Module:
         self.subscribe_mqtt(f"ombori/grid/message/{type}", handler)
 
     def on_event(self, type: str, cb):
-        self.subscribe(self, type, cb)
+        self.subscribe(type, cb)
 
     def publish(self, type: str, payload):
         data = json.dumps(payload)
         self.publish_mqtt(f"ombori/grid/message/{type}", data)
 
     def broadcast(self, type: str, payload):
-        self.publish(self, type, payload)
+        self.publish(type, payload)
 
     def publish_mqtt(self, topic: str, payload):
         if not self.client:
